Dispatch — Thorn 1.3.0 documentation

# Dispatch

Table of Contents:

- Introduction
- HTTP Client
- HTTP Headers
- HTTPS/SSL Requests

## Introduction

As soon as you call `event.send` the webhook will be dispatched by performing HTTP requests to all the subscriber URL’s matching the event.

The dispatch mechanism is configurable, and even supports pluggable backends.

There are three built-in dispatcher backends available:

- `"default"`

  > Dispatch requests directly in the current process.

  > In a web server the HTTP request will not complete until all of the Webhook requests have finished, so this is only suited for use in small installations and in development environments.

- `"disabled"`

  > Does not dispatch requests at all, useful for development.

- `"celery"`

  > Dispatch requests by sending a single Celery task for every event. The task will then be received by a worker which will start sending requests in batches to subscribers.

  > Since performing HTTP requests are entirely I/O bound, routing these tasks to workers running the eventlet or gevent pools are recommended (see Optimization and Performance).

  > The HTTP requests are also sorted by URL so that requests for the same domain have a high chance of being routed to the same process, to benefit from connection keep-alive settings, etc.

To configure the dispatcher used you need to change the `THORN_DISPATCHER` setting.

## HTTP Client

Thorn uses the requests library to perform HTTP requests, and will reuse a single `Session` for every thread/process.

## HTTP Headers

Thorn will provide the endpoints with standard HTTP header values

Header | Description
`Hook-Event` | Name of the event that triggered this delivery.
`Hook-Delivery` | Unique id for this delivery.
`Hook-HMAC` | HMAC digest that can be used to verify the sender
`Hook-Subscription` | Subscription UUID (can be used to cancel/modify)
`User-Agent` | User agent string, including Thorn and client version.
`Content-Type` | Delivery content type (e.g. application/json).

## HTTPS/SSL Requests

Thorn supports using `https://` URLs as callbacks, but for that to work the destination web server must be properly configured for HTTPS and have a valid server certificate.